netapp_ontap.raw_resource API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.raw_resource`

Copyright © 2026 NetApp Inc. All rights reserved.

This module defines the RawResource class. This class is meant to store resource information as a dictionary without schema validation to make fetching resources using fast_get_collection() possible. The class supports promoting a raw resource to proper resource using promote().

## Classes

`class RawResource (raw_data_dict: dict, resource_type, *args)`

  An Abstract class which is the base of resources that haven't had their schema validated.

  Initialize a RawResource Object

  ## Args

  `raw_data_dict` :`dict`
    the data the resource contains as returned from the host
  `resource_type` :`class`
    the class that this resource belongs to

  ### Methods

  `def promote (self)`

    Turn a raw resource into one that supports all applicable RESTful operations.

  `def set_connection (self, connection: HostConnection)`

    Set the connection attribute of the RawResource

    ## Args

    `connection` :`HostConnection`
      HostConnection object the resource belongs to